@@ -16,9 +16,7 @@ class Seed(int):
     @classmethod
     def from_response(cls, text: str) -> Seed:
         """Returns a seed from a server response."""
-        match = REGEX.fullmatch(text)
-
-        if match is None:
+        if (match := REGEX.fullmatch(text)) is None:
             raise ValueError('Unexpected seed response:', text)
 
         return cls(match.group(1))
